//package fonttest;

import java.awt.Color;
import java.awt.Font;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.MediaTracker;
import java.awt.event.MouseEvent;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Vector;

import javax.swing.ImageIcon;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.event.MouseInputAdapter;

//import fonttest.VirtualScreen.GraphicPanel;
//import fonttest.VirtualScreen.MapGraphic;
//import fonttest.VirtualScreen.SymbolGraphic;

public class MapSymbsTest {

	private static final int defaultFontSize = 26;
    private static final int opFontSize = 28;

    /**
     * This class encompasses all of the data necessary to render
     * a graphical symbol representing a warfighting entity.
     */
    class SymbolGraphic {
       
        public int heading;
        public double x, y;
        public Font font;
        public Color color;
        public char fillChar;
        public char symChar;
       
        // Offset character so that it is roughly centered on x,y
        public int offsetX, offsetY;

        public SymbolGraphic (){
        }

    }


    /**
     * This class encompasses all of the data necessary to render
     * a single tile of the topological map.
     */
    class MapGraphic {
        public Image image;
        public int x, y;

        public MapGraphic(Image image, int x, int y) {
            this.image = image;
            this.x = x;
            this.y = y;
        }
    }


    /**
     * This class keeps track of and paints all graphical entities.
     */
    class GraphicPanel extends JPanel {

        //** a list of map tiles
        private List maps;
        //** a mapping of enity ids to symbol graphics
        private Map symbolGraphics;
        //** a mapping of operation ids to tactical graphics
        private Map tacticalGraphics;

        private MediaTracker mt;
        private int mapCount;

        /**
         * constructor
         */
        public GraphicPanel() {
            super();

            maps = new Vector();
            symbolGraphics = new HashMap();
            SymbolGraphic sg = getSymbolGraphic();
            symbolGraphics.put("test1", sg);
            tacticalGraphics = new HashMap();
            mt = new MediaTracker(this);

            mapCount = 0;

            addMouseListener(new MouseInputAdapter(){
                    public void mouseClicked(MouseEvent e){
                        System.out.println("(" + e.getX() + "," + 
                                           e.getY() + ")");
                    }
                });
        }

        /**
         * Adds a new map image to the list of map tiles.
         */
        public void addMap(Image map, double x, double y) {
            MapGraphic mg;

            try {
                mt.addImage(map, mapCount);
                mt.waitForID(mapCount++);
            }
            catch (Exception e)
            {   e.printStackTrace();    }

            mg = new MapGraphic(map, (int)x, (int)y);
            maps.add(mg);
        }

       

        /**
         * Paints all of the graphical objects (maps and symbols).
         */
        public void paintComponent(Graphics g) {
            System.out.println("starting paintComponent.");    
            super.paintComponent(g);
            
            
            // draw symbol graphics
            Iterator sgi = (symbolGraphics.values()).iterator();
            SymbolGraphic sg;
            if (sgi != null) {
                while (sgi.hasNext()) {
                    ImageIcon ii;
                    sg = (SymbolGraphic)sgi.next();

                    // draw the fill color
                    g.setFont(sg.font);
                    g.setColor(sg.color);
                    g.drawString("" + sg.fillChar,
                                 (int)sg.x+sg.offsetX,
                                 (int)sg.y+sg.offsetY);
                    
                    // draw the 2525b symbol
                    g.setColor(Color.black);
                    g.drawString("" + sg.symChar,
                                 (int)sg.x+sg.offsetX,
                                 (int)sg.y+sg.offsetY);

                }
            }
        }
    }

    private JFrame jf;
    private GraphicPanel gp;

    private double startX, startY, countX, countY;

    public MapSymbsTest() {
    }

    

    public void init() {
        System.out.println("init() ...");
        jf = new JFrame("MapSymbsTest");
        jf.setSize(600, 600);

        gp = new GraphicPanel();
        gp.setBackground(Color.white);
        jf.getContentPane().add(gp); 
        jf.setVisible(true);
    }

   
    public SymbolGraphic getSymbolGraphic(){
    	SymbolGraphic sg = new SymbolGraphic();
    	sg.color = new Color(128, 224, 255);
    	//sg.font =;;
    	sg.fillChar = '\uF040';
    	sg.symChar = '\uF023';
    	Font font2 = new Font("MapSym-FR-AIR", Font.TRUETYPE_FONT, 100);
    	sg.font = font2;
    	sg.offsetX = 1;
    	sg.offsetY = 1;
    	sg.x = 120.00;
    	sg.y = 120.00;
    	return sg;
    }
    

    static public void main(String args[]) {
    	MapSymbsTest vic = new MapSymbsTest();
    	vic.init();
    }
}
